@@ -1,4 +1,4 @@
-# $Id: Directory.pm 43381 2015-05-28 16:52:16Z anton $
+# $Id: Directory.pm 45637 2016-09-05 14:08:10Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -159,10 +159,11 @@ field 'ssl' => 1;
 
 sub ldapError {
 	#callback heeft geen $self
-	warn "ldapError";
 	my $res = $self;
-	# code 4 is sizelimit exceeded
-	confess $res->error unless $res->code == 4;
+	warn "ldapError: ", $res->code;
+	# No confess: a stack trace shows parameters like username and password printed on failure
+	#  code 4 is sizelimit exceeded
+	die( "ldapError: ". $res->error) unless $res->code == 4;
 	return $res;
 }
 
@@ -301,7 +302,10 @@ sub verify_password {
 	return $err unless ($entry);
 
 	my $dn = $entry->dn;
-	eval { $ldap->bind($dn, password => $password) };
+	eval { 
+		local $SIG{__DIE__};
+		$ldap->bind($dn, password => $password) 
+	};
 	$err = $@;
 	# fixme, verander dit in 'getFallbackPassword'
 
@@ -315,7 +319,10 @@ sub verify_password {
 		# vergeet niet de \n eraf te slopen!
 		chomp $converted;
 		warn "converted: $converted" if $debug;
-		eval { $ldap->bind($dn, password => $converted) };
+		eval { 
+			local $SIG{__DIE__};
+			$ldap->bind($dn, password => $converted) 
+		};
 		$err = $@;
 	}
 	# Maak er weer een anonymous bind van
